@@ -15,6 +15,8 @@ class LunarYear:
 
     __LEAP = {}
 
+    __CACHE = {}
+
     for i in range(0, len(__LEAP_11)):
         __LEAP[__LEAP_11[i]] = 13
     for i in range(0, len(__LEAP_12)):
@@ -27,8 +29,13 @@ class LunarYear:
         self.compute()
 
     @staticmethod
-    def fromYear(year):
-        return LunarYear(year)
+    def fromYear(lunar_year):
+        if lunar_year not in LunarYear.__CACHE:
+            obj = LunarYear(lunar_year)
+            LunarYear.__CACHE[lunar_year] = obj
+        else:
+            obj = LunarYear.__CACHE[lunar_year]
+        return obj
 
     def compute(self):
         from . import Lunar, Solar, LunarMonth
